
/* Generated data (by glib-mkenums) */

#ifndef CC_ENUMERATIONS_H
#define CC_ENUMERATIONS_H

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "cc-item.h" */
GType cc_item_flags_get_type (void);
#define CC_TYPE_ITEM_FLAGS (cc_item_flags_get_type())

/* enumerations from "cc-unit.h" */
GType cc_unit_get_type (void);
#define CC_TYPE_UNIT (cc_unit_get_type())

/* enumerations from "cc-utils.h" */
GType cc_zoom_mode_get_type (void);
#define CC_TYPE_ZOOM_MODE (cc_zoom_mode_get_type())

G_END_DECLS

#endif /* !CC_ENUMERATIONS_H */

/* Generated data ends here */

